Condition

Struct Condition 

pub struct Condition<I> { /* private fields */ }
Condition.

Conditions are used to determine whether a Barrier contains a specific identifier. They implement Value, so they can be created and returned by any Operator. The resulting Stream of conditions can be used in any operator that expects conditions, such as Stream::select.

Examples

use zrx_stream::barrier::Condition;

// Create condition and test identifier
let condition = Condition::new(|&id: &i32| id < 100);
assert!(condition.satisfies(&42));

Implementations

Source

impl<I> Condition<I>

pub fn new<F>(f: F) -> Self
where F: ConditionFn<I> + 'static,

Creates a condition.

Examples
use zrx_stream::barrier::Condition;

// Create condition
let condition = Condition::new(|&id: &i32| id < 100);
pub fn satisfies(&self, id: &I) -> bool

Returns whether the given identifier satisfies the condition.

Examples
use zrx_stream::barrier::Condition;

// Create condition and test identifier
let condition = Condition::new(|&id: &i32| id < 100);
assert!(condition.satisfies(&42));