StreamSetExt

Trait StreamSetExt 

pub trait StreamSetExt<I, T>: IntoStreamSet<I, T> + Sized
where I: Id, T: Value + Clone + Eq,
{ // Provided methods fn union(self) -> Option<Stream<I, T>> { ... } fn intersection(self) -> Option<Stream<I, T>> { ... } fn difference(self) -> Option<Stream<I, T>> { ... } fn coalesce(self) -> Option<Stream<I, T>> { ... } }
Extension of StreamSet.

Although, conceptually, this extension trait does belong to StreamSet, allowing to conveniently work with data types that can be converted into a set of streams, it is deliberately implemented for anything that converts via IntoStreamSet, as this offers more flexibilty.

Provided Methods

fn union(self) -> Option<Stream<I, T>>

fn intersection(self) -> Option<Stream<I, T>>

fn difference(self) -> Option<Stream<I, T>>

fn coalesce(self) -> Option<Stream<I, T>>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<'a, S, I, T> StreamSetExt<I, T> for S
where S: IntoIterator<Item = &'a Stream<I, T>>, I: Id, T: Value + Clone + Eq,