pub trait StreamTupleJoin<I, P>: StreamTuple<I>where
P: Presence,{
type Item: Tuple<P>;
}Expand description
Stream tuple join.
Stream tuples are heterogeneous collections of streams, which is why they
are the natural choice to represent joins. This trait is implemented for
tuples of streams in sizes of 1 to 8, and is further specialized with the
Presence markers to implement the following join strategies:
All: All items are required (inner join).First: Only the first item is required (left join).Any: All items are optional (outer join)
Extensions of this trait include:
Keeping the concretization of tuples of sizes 1 to 8 together with presence markers in this base trait allows to keep the join implementations focused.
Required Associated Types
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.