with_splat

Function with_splat 

pub fn with_splat<F>(f: F) -> WithSplat<F>
Splats the function’s arguments.

Function traits that implement this trait allow to pass a function that receives a splat argument instead of a single tuple argument.

Note that there are no trait bounds, since [WithSplat] is merely a marker struct that is used to differentiate between function implementations. This is also why the returned type implements Deref, so that it behaves like the underlying function.

Examples

use zrx_stream::function::{with_splat, InspectFn};

// Define and execute function
let f = |&a: &i32, &b: &i32| println!("({a}, {b})");
with_splat(f).execute(&"id", &(1, 2))?;