FilterFn

Trait FilterFn 

pub trait FilterFn<I, T>: Send + 'static
where T: ?Sized,
{ // Required method fn execute(&self, id: &I, data: &T) -> Result<bool>; }
Filter function.

This trait defines a function that can be used to filter data of type T. It expects borrowed data and should return a bool value to indicate to the caller whether it should exclude it from further processing, or to just pass it through as it is.

There’s a range of different implementations of this trait, allowing you to use a variety of function shapes, including support for Splat, as well as support for the [WithId] and [WithSplat] adapters. Furthermore, the trait can be implemented for custom types to add new behaviors. Note that all implementations also allow to return a Report, which makes it possible to return diagnostics from the function execution.

The 'static lifetimes is mandatory as closures must be moved into actions, so requiring it here allows us to reduce the verbosity of trait bounds.

Examples

Filter data:

use zrx_stream::function::FilterFn;

// Define and execute function
let f = |&n: &i32| n > 0;
f.execute(&"id", &42)?;

Filter data with splat argument:

use zrx_stream::function::{FilterFn, Splat};

// Define and execute function
let f = |&a: &i32, &b: &i32| a < b;
f.execute(&"id", Splat::from_ref(&(1, 2)))?;

Required Methods

fn execute(&self, id: &I, data: &T) -> Result<bool>

Executes the filter function.

Errors

This method returns an error if the function fails to execute.

Implementors

Source

impl<F, R, I, T1> FilterFn<I, Splat<(T1,)>> for F
where F: Fn(&T1) -> R + Send + 'static, R: IntoReport<bool>, I: Display,

Source

impl<F, R, I, T1, T2> FilterFn<I, Splat<(T1, T2)>> for F
where F: Fn(&T1, &T2) -> R + Send + 'static, R: IntoReport<bool>, I: Display,

Source

impl<F, R, I, T1, T2, T3> FilterFn<I, Splat<(T1, T2, T3)>> for F
where F: Fn(&T1, &T2, &T3) -> R + Send + 'static, R: IntoReport<bool>, I: Display,

Source

impl<F, R, I, T1, T2, T3, T4> FilterFn<I, Splat<(T1, T2, T3, T4)>> for F
where F: Fn(&T1, &T2, &T3, &T4) -> R + Send + 'static, R: IntoReport<bool>, I: Display,

Source

impl<F, R, I, T1, T2, T3, T4, T5> FilterFn<I, Splat<(T1, T2, T3, T4, T5)>> for F
where F: Fn(&T1, &T2, &T3, &T4, &T5) -> R + Send + 'static, R: IntoReport<bool>, I: Display,

Source

impl<F, R, I, T1, T2, T3, T4, T5, T6> FilterFn<I, Splat<(T1, T2, T3, T4, T5, T6)>> for F
where F: Fn(&T1, &T2, &T3, &T4, &T5, &T6) -> R + Send + 'static, R: IntoReport<bool>, I: Display,

Source

impl<F, R, I, T1, T2, T3, T4, T5, T6, T7> FilterFn<I, Splat<(T1, T2, T3, T4, T5, T6, T7)>> for F
where F: Fn(&T1, &T2, &T3, &T4, &T5, &T6, &T7) -> R + Send + 'static, R: IntoReport<bool>, I: Display,

Source

impl<F, R, I, T1, T2, T3, T4, T5, T6, T7, T8> FilterFn<I, Splat<(T1, T2, T3, T4, T5, T6, T7, T8)>> for F
where F: Fn(&T1, &T2, &T3, &T4, &T5, &T6, &T7, &T8) -> R + Send + 'static, R: IntoReport<bool>, I: Display,

Source

impl<F, R, I, T> FilterFn<I, T> for F
where F: Fn(&T) -> R + Send + 'static, R: IntoReport<bool>, I: Display, T: Value + ?Sized,