SelectFn

Trait SelectFn 

pub trait SelectFn<I, T, S>: Send + 'static
where T: ?Sized,
{ // Required method fn execute(&self, id: &I, data: &T) -> Result<S>; }
Select function.

This trait defines a function that can be used to select data from an item, e.g., to extract a key to group items or to compute a duration for a timer.

There’s a range of different implementations of this trait, allowing you to use a variety of function shapes, including support for Splat, as well as support for the [WithId] and [WithSplat] adapters. Furthermore, the trait can be implemented for custom types to add new behaviors. Note that all implementations also allow to return a Report, which makes it possible to return diagnostics from the function execution.

The 'static lifetimes is mandatory as closures must be moved into actions, so requiring it here allows us to reduce the verbosity of trait bounds.

Examples

Group by odd/even:

use zrx_stream::function::SelectFn;

// Define and execute function
let f = |&n: &i32| n & 1;
f.execute(&"id", &42)?;

Required Methods

fn execute(&self, id: &I, data: &T) -> Result<S>

Executes the select function.

Errors

This method returns an error if the function fails to execute.

Implementors

Source

impl<F, R, I, T1, S> SelectFn<I, Splat<(T1,)>, S> for F
where F: Fn(&T1) -> R + Send + 'static, R: IntoReport<S>, I: Display,

Source

impl<F, R, I, T1, T2, S> SelectFn<I, Splat<(T1, T2)>, S> for F
where F: Fn(&T1, &T2) -> R + Send + 'static, R: IntoReport<S>, I: Display,

Source

impl<F, R, I, T1, T2, T3, S> SelectFn<I, Splat<(T1, T2, T3)>, S> for F
where F: Fn(&T1, &T2, &T3) -> R + Send + 'static, R: IntoReport<S>, I: Display,

Source

impl<F, R, I, T1, T2, T3, T4, S> SelectFn<I, Splat<(T1, T2, T3, T4)>, S> for F
where F: Fn(&T1, &T2, &T3, &T4) -> R + Send + 'static, R: IntoReport<S>, I: Display,

Source

impl<F, R, I, T1, T2, T3, T4, T5, S> SelectFn<I, Splat<(T1, T2, T3, T4, T5)>, S> for F
where F: Fn(&T1, &T2, &T3, &T4, &T5) -> R + Send + 'static, R: IntoReport<S>, I: Display,

Source

impl<F, R, I, T1, T2, T3, T4, T5, T6, S> SelectFn<I, Splat<(T1, T2, T3, T4, T5, T6)>, S> for F
where F: Fn(&T1, &T2, &T3, &T4, &T5, &T6) -> R + Send + 'static, R: IntoReport<S>, I: Display,

Source

impl<F, R, I, T1, T2, T3, T4, T5, T6, T7, S> SelectFn<I, Splat<(T1, T2, T3, T4, T5, T6, T7)>, S> for F
where F: Fn(&T1, &T2, &T3, &T4, &T5, &T6, &T7) -> R + Send + 'static, R: IntoReport<S>, I: Display,

Source

impl<F, R, I, T1, T2, T3, T4, T5, T6, T7, T8, S> SelectFn<I, Splat<(T1, T2, T3, T4, T5, T6, T7, T8)>, S> for F
where F: Fn(&T1, &T2, &T3, &T4, &T5, &T6, &T7, &T8) -> R + Send + 'static, R: IntoReport<S>, I: Display,

Source

impl<F, R, I, T, S> SelectFn<I, T, S> for F
where F: Fn(&T) -> R + Send + 'static, R: IntoReport<S>, I: Display, T: Value + ?Sized,