Chunk

Struct Chunk 

pub struct Chunk<I, T> { /* private fields */ }
Chunk of items.

This data type represents a collection of items that are grouped together for processing. Unlike Delta, a Chunk contains items that are all present (i.e., not optional). Chunks are used to process a batch of items as a single unit, e.g., for windowing or pagination.

Note that chunks are assumed to always only contain unique items, meaning there are no two items with the same identifier in a chunk. This invariant must be checked with unit tests (which we provide for our operators), but is not enforced at runtime for performance reasons.

Examples

use zrx_scheduler::effect::Item;
use zrx_stream::value::Chunk;

// Create chunk of items
let chunk = Chunk::from([
    Item::new("a", 1),
    Item::new("b", 2),
    Item::new("c", 3),
]);

Implementations

Source

impl<I, T> Chunk<I, T>

pub fn iter(&self) -> Iter<'_, Item<I, T>>

Creates an iterator over the chunk of items.

Examples
use zrx_scheduler::effect::Item;
use zrx_stream::value::Chunk;

// Create chunk of items
let chunk = Chunk::from([
    Item::new("a", 1),
    Item::new("b", 2),
    Item::new("c", 3),
]);

// Create iterator over items
for item in chunk.iter() {
    println!("{item:?}");
}