Delta

Struct Delta 

pub struct Delta<I, T> { /* private fields */ }
Delta of items.

This data type represents a collection of items that can include insertions and deletions (if Option is None), which we call deltas. Deltas are the means of differentially passing changes through a stream. They must be applied to a store to manifest the changes they represent.

Note that deltas are assumed to always only contain unique items, meaning there are no two items with the same identifier in a delta. This invariant must be checked with unit tests (which we provide for our operators), but is not enforced at runtime for performance reasons. Differential semantics still hold if this invariant is violated, but performance might be impacted due to unnecessary re-computations.

Examples

use zrx_scheduler::effect::Item;
use zrx_stream::value::Delta;

// Create delta of items
let delta = Delta::from([
    Item::new("a", Some(1)),
    Item::new("b", Some(2)),
    Item::new("c", Some(3)),
]);

Implementations

Source

impl<I, T> Delta<I, T>

pub fn iter(&self) -> Iter<'_, Item<I, Option<T>>>

Creates an iterator over the delta of items.

Examples
use zrx_scheduler::effect::Item;
use zrx_stream::value::Delta;

// Create delta of items
let delta = Delta::from([
    Item::new("a", Some(1)),
    Item::new("b", Some(2)),
    Item::new("c", Some(3)),
]);

// Create iterator over items
for item in delta.iter() {
    println!("{item:?}");
}