Position

Struct Position 

pub struct Position<T> {
    pub index: usize,
    pub value: T,
}
Position.

This data type attaches an index to a value, indicating its position within a sorted stream. It is primarily used in the context of Stream::sort, which keeps an internal store of items and updates their positions as the items entering the stream change.

Note that ordering of positions is determined by their index, and in case a tie-breaker is necessary, by the value itself.

Fields

index: usize

Index in sort order.

value: T

Associated value.

Implementations

Source

impl<T> Position<T>

pub fn new(index: usize, value: T) -> Self

Creates a position.

Examples
use zrx_stream::value::Position;

// Create position
let position = Position::new(0, "a");
pub fn into_parts(self) -> (usize, T)

Returns the index and associated value, consuming the position.

Examples
use zrx_stream::value::Position;

// Create position
let position = Position::new(0, "a");
assert_eq!(
    position.into_parts(),
    (0, "a"),
);
pub fn into_value(self) -> T

Returns the associated value, consuming the position.

use zrx_stream::value::Position;

// Create position
let position = Position::new(0, "a");
assert_eq!(position.into_value(), "a");