pub struct Condition<I> { /* private fields */ }Expand description
Condition.
Conditions are used to determine whether a Barrier contains a specific
identifier. They implement Value, so they can be created and returned by
any Operator. The resulting Stream of conditions can be used in
any operator that expects conditions, such as Stream::select.
Examples
use zrx_stream::barrier::Condition;
// Create condition and test identifier
let condition = Condition::new(|&id: &i32| id < 100);
assert!(condition.satisfies(&42));Implementations