pub trait StreamTupleCons<I, T> {
type Output: StreamTuple<I>;
// Required method
fn cons(head: Stream<I, T>, tail: Self) -> Self::Output;
}Expand description
Stream tuple construction.
This trait is used to prepend streams to existings stream tuples, which is
necessary to implement stream methods that take a tuple of streams, as they
need to be combined with the current stream (i.e. self) to construct a
stream tuple for further consumption.
Required Associated Types
Sourcetype Output: StreamTuple<I>
type Output: StreamTuple<I>
Output type of construction.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.