pub trait FilterFn<I, T>: Send + 'staticwhere
T: ?Sized,{
// Required method
fn execute(&self, id: &I, data: &T) -> Result<bool>;
}Expand description
Filter function.
This trait defines a function that can be used to filter data of type T.
It expects borrowed data and should return a bool value to indicate to
the caller whether it should exclude it from further processing, or to just
pass it through as it is.
There’s a range of different implementations of this trait, allowing you to
use a variety of function shapes, including support for Splat, as well
as support for the [WithId] and [WithSplat] adapters. Furthermore, the
trait can be implemented for custom types to add new behaviors. Note that
all implementations also allow to return a Report, which makes it
possible to return diagnostics from the function execution.
The 'static lifetimes is mandatory as closures must be moved into actions,
so requiring it here allows us to reduce the verbosity of trait bounds.
Examples
Filter data:
use zrx_stream::function::FilterFn;
// Define and execute function
let f = |&n: &i32| n > 0;
f.execute(&"id", &42)?;Filter data with splat argument:
use zrx_stream::function::{FilterFn, Splat};
// Define and execute function
let f = |&a: &i32, &b: &i32| a < b;
f.execute(&"id", Splat::from_ref(&(1, 2)))?;