pub trait InspectFn<I, T>: Send + 'staticwhere
T: ?Sized,{
// Required method
fn execute(&self, id: &I, data: &T) -> Result;
}Expand description
Inspect function.
This trait defines a function that can be used to inspect borrowed data in a stream without modifying it, and is not expected to return new data.
There’s a range of different implementations of this trait, allowing you to
use a variety of function shapes, including support for Splat, as well
as support for the [WithId] and [WithSplat] adapters. Furthermore, the
trait can be implemented for custom types to add new behaviors. Note that
all implementations also allow to return a Report, which makes it
possible to return diagnostics from the function execution.
The 'static lifetimes is mandatory as closures must be moved into actions,
so requiring it here allows us to reduce the verbosity of trait bounds.
Examples
Inspect data:
use zrx_stream::function::InspectFn;
// Define and execute function
let f = |&n: &i32| println!("{n}");
f.execute(&"id", &42)?;Inspect data with splat argument:
use zrx_stream::function::{InspectFn, Splat};
// Define and execute function
let f = |&a: &i32, &b: &i32| println!("{a} < {b}");
f.execute(&"id", Splat::from_ref(&(1, 2)))?;