Workflow

Struct Workflow 

pub struct Workflow<I> { /* private fields */ }
Workflow.

Implementations

Source

impl<I> Workflow<I>
where I: Id,

pub fn builder() -> Builder<I>

Creates a workflow builder.

If possible, it’s recommended to use Workflow::with instead, as it creates a Builder which is only valid for the function lifetime.

pub fn with<F, E>(f: F) -> Result<Self, E>
where F: FnOnce(Builder<I>) -> Result<(), E>, E: Error,

Creates a workflow from the builder passed to the given function.

Errors

If the given function returns an error, it is returned.