pub struct Position<T> {
pub index: usize,
pub value: T,
}Expand description
Position.
This data type attaches an index to a value, indicating its position within
a sorted stream. It is primarily used in the context of Stream::sort,
which keeps an internal store of items and updates their positions as the
items entering the stream change.
Note that ordering of positions is determined by their index, and in case a tie-breaker is necessary, by the value itself.
Fields
index: usizeIndex in sort order.
value: TAssociated value.
Implementations
Sourceimpl<T> Position<T>
impl<T> Position<T>
Sourcepub fn new(index: usize, value: T) -> Self
pub fn new(index: usize, value: T) -> Self
Creates a position.
Examples
use zrx_stream::value::Position;
// Create position
let position = Position::new(0, "a");Sourcepub fn into_parts(self) -> (usize, T)
pub fn into_parts(self) -> (usize, T)
Returns the index and associated value, consuming the position.
Examples
use zrx_stream::value::Position;
// Create position
let position = Position::new(0, "a");
assert_eq!(
position.into_parts(),
(0, "a"),
);Sourcepub fn into_value(self) -> T
pub fn into_value(self) -> T
Returns the associated value, consuming the position.
use zrx_stream::value::Position;
// Create position
let position = Position::new(0, "a");
assert_eq!(position.into_value(), "a");Trait Implementations
Sourceimpl<T: Ord> Ord for Position<T>
impl<T: Ord> Ord for Position<T>
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<T: PartialOrd> PartialOrd for Position<T>
impl<T: PartialOrd> PartialOrd for Position<T>
impl<T: Eq> Eq for Position<T>
impl<T> StructuralPartialEq for Position<T>
impl<T> Value for Position<T>where
T: Value,