pub trait Tuple<P>: Value {
type Arguments<'a>: TryFromValues<'a> + IntoOwned<Owned = Self>;
}Expand description
Tuple.
This trait is used to define different configurations of tuples for join operators, which centers around the presence of values in the tuple. Note that the argument type defines the expected values in the tuple, and is used as the join operator’s own argument type.
In order to isolate lifetimes in the trait, and to omit the need for using higher-ranked trait bounds in each operator, the implementations account for the lifetimes with said higher-ranked trait bounds. While they are rather ugly, there’s no other way to express it without them.
This trait doesn’t have a bound on Presence, so we can keep operator
implementations simpler, but it’s enforced on wrappers that use it.
Required Associated Types
Sourcetype Arguments<'a>: TryFromValues<'a> + IntoOwned<Owned = Self>
type Arguments<'a>: TryFromValues<'a> + IntoOwned<Owned = Self>
Tuple arguments type.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.